@@ -243,6 +243,9 @@ static Token::Operator matchOperator(const QString& text)
         case '/':
             result = Token::Division;
             break;
+        case '%':
+            result = Token::Percent;
+            break;
         case '^':
             result = Token::Exponentiation;
             break;
@@ -311,6 +314,9 @@ static int opPrecedence(Token::Operator op)
     case Token::IntegerDivision:
         prec = 600;
         break;
+    case Token::Percent:
+        prec = 800;
+        break;
     case Token::Addition:
     case Token::Subtraction:
         prec = 300;
@@ -1307,6 +1313,12 @@ void Evaluator::compile(const Tokens& tokens)
                        syntaxStack.reduce(2);
                        m_codes.append(Opcode(Opcode::Fact));
                        break;
+                   case Token::Percent:
+                       syntaxStack.pop();
+                       m_constants.append(HNumber("0.01"));
+                       m_codes.append(Opcode(Opcode::Load, m_constants.count() - 1));
+                       m_codes.append(Opcode(Opcode::Mul));
+                       break;
                    default:;
                    }
                }
