@@ -2,14 +2,26 @@
 <!DOCTYPE TS>
 <TS version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
         <translation type="unfinished"></translation>
@@ -20,13 +32,9 @@
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
+        <source>Expression Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
