@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
-        <translation>خطأ في المصطح</translation>
-    </message>
-</context>
-<context>
-    <name>Main</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>حاسبة ديبين</translation>
-    </message>
-    <message>
-        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>حاسبة ديبين : إنها بسيطة وسهلة لاستخدمات سطح المكتب ، تدعم عمليات الجمع والطرح والضرب والقسمة.</translation>
+        <translation>خطأ في الصيغة</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>حاسبة ديبين</translation>
-    </message>
     <message>
         <source>Dark Theme</source>
         <translation>سمة داكنة</translation>
     </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>النمط البسيط</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>النمط العلمي</translation>
+    </message>
+    <message>
+        <source>Deepin Calculator</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>SimpleListDelegate</name>
+    <message>
+        <source>Expression Error</source>
+        <translation>خطأ في الصيغة</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
