@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>Error d&apos;expressió</translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>Tema fosc</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Mode simple</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Mode científic</translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
         <translation>Calculadora del Deepin</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>La calculadora del Deepin és una calculadora d&apos;escriptori senzilla i fàcil d&apos;usar. Admet sumar, restar, multiplicar i dividir amb resta.</translation>
+        <translation>La calculadora del Deepin és una calculadora d&apos;escriptori senzilla i fàcil d&apos;usar. Admet sumar, restar, multiplicar i dividir.</translation>
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>Calculadora del Deepin</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>Tema fosc</translation>
+        <source>Expression Error</source>
+        <translation>Error d&apos;expressió</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
