@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>Error de expresión</translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>Tema oscuro</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Modo simple</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Modo científico</translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
         <translation>Calculadora Deepin</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>Deepin Calculator es una calculadora de escritorio simple y fácil de usar. Es compatible con la suma, la resta, la multiplicación y la división.</translation>
+        <translation>La calculadora deepin es una calculadora de escritorio fácil de usar. Soporta sumas, rectas, multiplicaciones y divisiones</translation>
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>Calculadora Deepin</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>Tema oscuro</translation>
+        <source>Expression Error</source>
+        <translation>Error de expresión</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
