@@ -1,16 +1,28 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation type="unfinished"/>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>Tamna tema</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Deepin Calculator</source>
-        <translation>Deepin kalkukator</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
@@ -18,14 +30,10 @@
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin kalkukator</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>Tamna tema</translation>
+        <source>Expression Error</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
