@@ -1,13 +1,25 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>Errore dell&apos;espressione</translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>Tema scuro</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Modalità semplice</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Modalità scientifica</translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
         <translation>Deepin Calculator</translation>
@@ -19,14 +31,10 @@ Localizzazione italiana a cura di Massimo A. Carofano. </translation>
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin Calculator</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>Tema scuro</translation>
+        <source>Expression Error</source>
+        <translation>Errore dell&apos;espressione</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
