@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
-        <translation type="unfinished"/>
+        <translation>Reiškinio klaida</translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>Tamsi tema</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Paprasta veiksena</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Mokslinė veiksena</translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
         <translation>Deepin skaičiuotuvas</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation type="unfinished"/>
+        <translation>Deepin skaičiuotuvas yra paprastas ir lengvas naudoti darbalaukio skaičiuotuvas. Jis palaiko sudėtį, atimtį, daugybą ir dalybą.</translation>
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin skaičiuotuvas</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>Tamsi tema</translation>
+        <source>Expression Error</source>
+        <translation>Reiškinio klaida</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
