@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
-        <translation>Uitdrukking fout</translation>
+        <translation>Uitdrukkingsfout</translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>Donker thema</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Eenvoudige modus</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Wetenschappelijke modus</translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
         <translation>Deepin Rekenmachine</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>Deepin Rekenmachine is een eenvoudige en gebruiksvriendelijke desktop rekenmachine. Het ondersteunt optellen, aftrekken, vermenigvuldigen en delen.</translation>
+        <translation>Deepin Rekenmachine is een eenvoudige, makkelijk te gebruiken rekenmachine met ondersteuning voor optellen, aftrekken, vermenigvuldigen en delen.</translation>
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin Rekenmachine</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>Donker Thema</translation>
+        <source>Expression Error</source>
+        <translation>Uitdrukkingsfout</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
