@@ -1,13 +1,25 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>Błąd wyrażenia matematycznego</translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>Motyw ciemny</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Tryb prosty</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Tryb naukowy</translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
         <translation>Kalkulator Deepin</translation>
@@ -18,14 +30,10 @@
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>Kalkulator Deepin</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>Motyw ciemny</translation>
+        <source>Expression Error</source>
+        <translation>Błąd wyrażenia matematycznego</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
