@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>Erro de expressão </translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>Tema Escuro</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Modo Simples</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Modo Científico</translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
-        <translation>Calculadora Deepin</translation>
+        <translation>Deepin Calculator</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>Calculadora Deepin é uma calculadora simples e fácil de usar no desktop. Ela suporta operações como adição, subtração, multiplicação e divisão.</translation>
+        <translation>O Deepin Calculator é uma calculadora de desktop simples e fácil de usar. Ele suporta adição, subtração, multiplicação e divisão.</translation>
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>Calculadora Deepin</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>Tema dark</translation>
+        <source>Expression Error</source>
+        <translation>Erro de expressão </translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
