@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>Ошибка Выражения</translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>Темная Тема</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Простой Режим</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Научный Режим</translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
         <translation>Калькулятор Deepin</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>Калькулятор Deepin - простой и удобный настольный калькулятор. Deepin Calculator - простой и удобный настольный калькулятор. Он поддерживает сложение, вычитание, умножение и деление.</translation>
+        <translation>Калькулятор Deepin - простой и удобный в использовании настольный калькулятор. Он поддерживает сложение, вычитание, умножение и деление.</translation>
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>Калькулятор Deepin</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>Темная Тема</translation>
+        <source>Expression Error</source>
+        <translation>Ошибка Выражения</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
