@@ -22,11 +22,11 @@
     </message>
     <message>
         <source>Deepin Calculator</source>
-        <translation type="unfinished"/>
+        <translation>Deepin Kalkulačka</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation type="unfinished"/>
+        <translation>Deepin Kalkulačka je jednoduchá a ľahko použiteľná desktopová kalkulačka. Podporuje sčítanie, odčítanie, násobenie a delenie.</translation>
     </message>
 </context>
 <context>
