@@ -3,37 +3,37 @@
     <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
-        <translation type="unfinished"/>
+        <translation>Грешка израза</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
         <source>Dark Theme</source>
-        <translation>Мрачна тема</translation>
+        <translation>Tамна тема</translation>
     </message>
     <message>
         <source>Simple mode</source>
-        <translation type="unfinished"/>
+        <translation>Једноставан режим</translation>
     </message>
     <message>
         <source>Scientific mode</source>
-        <translation type="unfinished"/>
+        <translation>Научни режим</translation>
     </message>
     <message>
         <source>Deepin Calculator</source>
-        <translation type="unfinished"/>
+        <translation>Дипин Калкулатор</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation type="unfinished"/>
+        <translation>Дипин Калкулатор је једноставан и лак за коришћење рачунарски калкулатор. Подржава сабирање, одузимање, множење и дељење.</translation>
     </message>
 </context>
 <context>
     <name>SimpleListDelegate</name>
     <message>
         <source>Expression Error</source>
-        <translation type="unfinished"/>
+        <translation>Грешка израза</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
