@@ -1,13 +1,25 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>表达式错误</translation>
     </message>
 </context>
 <context>
-    <name>Main</name>
+    <name>MainWindow</name>
+    <message>
+        <source>Dark Theme</source>
+        <translation>深色主题</translation>
+    </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>简单模式</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>科学模式</translation>
+    </message>
     <message>
         <source>Deepin Calculator</source>
         <translation>深度计算器</translation>
@@ -18,14 +30,10 @@
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>SimpleListDelegate</name>
     <message>
-        <source>Deepin Calculator</source>
-        <translation>深度计算器</translation>
-    </message>
-    <message>
-        <source>Dark Theme</source>
-        <translation>深色主题</translation>
+        <source>Expression Error</source>
+        <translation>表达式错误</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
